@@ -1,7 +1,9 @@
 """
-This module offers ``get_*`` methods to check for empty files, misindented JSON files, and invalid JSON files. See "pytest examples" for usage examples.
+This module offers ``get_*`` functions to check for empty files, misindented JSON files, and invalid JSON files. See
+"pytest example" in each function's documentation for usage examples.
 
-This module also offers ``validate_*`` methods to test JSON Schema. Each method's behavior is customizable, and not all methods are relevant to all schema.
+This module also offers ``validate_*`` methods to test JSON Schema. Each method's behavior is customizable, and not all
+methods are relevant to all schema.
 
 The typical usage is to first define a test method like so:
 
@@ -18,7 +20,8 @@ The typical usage is to first define a test method like so:
    def test_schema_valid(path, name, data):
        validate_json_schema(path, name, data, metaschema)
 
-You can edit ``metaschema`` to be more strict and/or to add new properties. Then, define the ``validate_json_schema`` method that uses the ``validate_*`` methods. For example:
+You can edit ``metaschema`` to be more strict and/or to add new properties. Then, define the ``validate_json_schema``
+method that uses the ``validate_*`` methods. For example:
 
 .. code-block:: python
 
@@ -62,9 +65,12 @@ You can monkeypatch ``warnings.formatwarning`` to customize and abbreviate the w
        return str(message).replace(cwd + os.sep, '')
 
    warnings.formatwarning = formatwarning
-"""  # noqa: E501
+"""
+
+# In this module, it would be simpler to use a tuple for each `pointer` keyword argument, especially when calculating
+# the last component of the pointer (the "parent"). However, it's easier when *using* the module to write JSON Pointers
+# as strings. Therefore, we use strings instead of tuples.
 
-import _csv
 import csv
 import json
 import os
@@ -210,7 +216,7 @@ def get_invalid_csv_files():
             with open(path, newline='') as f:
                 try:
                     csv.DictReader(f)
-                except _csv.Error as e:
+                except csv.Error as e:
                     yield path, e
 
 
@@ -274,7 +280,7 @@ def validate_metadata_presence(*args, allow_missing=_false):
     """
     Warns and returns the number of errors relating to metadata in a JSON Schema.
 
-    The root schema and each field must have `"type" <https://tools.ietf.org/html/draft-fge-json-schema-validation-00#section-5.5.2>`__
+    The root schema and each field must have `"type" <https://tools.ietf.org/html/draft-fge-json-schema-validation-00#section-5.5.2>`__,
     `"title" and "description" <https://tools.ietf.org/html/draft-fge-json-schema-validation-00#section-6.1>`__
     properties, unless it has a `"$ref" <https://tools.ietf.org/html/draft-pbryan-zyp-json-ref-03>`__ property.
 
@@ -305,7 +311,7 @@ def validate_metadata_presence(*args, allow_missing=_false):
                     errors += 1
                     warn('{} is missing "{}" at {}'.format(path, prop, pointer), MetadataPresenceWarning)
 
-            if 'type' not in data and '$ref' not in data and 'oneOf' not in data:
+            if 'type' not in data and '$ref' not in data and 'oneOf' not in data and not allow_missing(pointer):
                 errors += 1
                 warn('{} is missing "type" or "$ref" or "oneOf" at {}'.format(path, pointer), MetadataPresenceWarning)
 
@@ -319,13 +325,12 @@ def validate_null_type(path, data, pointer='', no_null=False, expect_null=True,
     """
     Warns and returns the number of errors relating to non-nullable optional fields and nullable required fields.
 
-    If :code:`no_null` is ``True``, then `"type" <https://tools.ietf.org/html/draft-fge-json-schema-validation-00#section-5.5.2>`__
-    properties mustn't include "null".
+    If :code:`no_null` is ``True``, then "type" properties mustn't include "null".
 
-    Otherwise, the "type" properties for objects and :meth:`arrays of objects<json.schema.is_array_of_objects>` mustn't
-    include "null". If a field is `required <https://tools.ietf.org/html/draft-fge-json-schema-validation-00#section-5.4.3>`__,
-    its "type" property mustn't include "null". If a field isn't required, and it isn't an object or array of objects,
-    its "type" property must include "null".
+    Otherwise, the "type" properties for objects and arrays of objects mustn't include "null". If a field is `required
+    <https://tools.ietf.org/html/draft-fge-json-schema-validation-00#section-5.4.3>`__, then its "type" property
+    mustn't include "null". If a field isn't required (and it isn't an object or array of objects), then its "type"
+    property must include "null".
 
     :param bool no_null: whether the standard disallows "null" in the "type" property of any field
     :param bool expect_null: whether the field, in context, is expected to have "null" in its "type" property
@@ -337,7 +342,7 @@ def validate_null_type(path, data, pointer='', no_null=False, expect_null=True,
     :type allow_null: list, tuple or set
     :returns: the number of errors
     :rtype: int
-    """  # noqa: E501
+    """
     errors = 0
 
     kwargs = {
@@ -389,8 +394,8 @@ def validate_codelist_enum(*args, fallback=None, allow_enum=_false, allow_missin
     """
     Warns and returns the number of errors relating to codelists in a JSON Schema.
 
-    If a field has a "codelist" property but no "type" property, its "type" is assumed to be "array", unless a fallback
-    "type" is provided via :code:`fallback`.
+    If a field has a "codelist" property but no "type" property (e.g. if the "codelist" property is being overwritten),
+    then its "type" is assumed to be "array" unless a fallback "type" is provided via :code:`fallback`.
 
     If the "codelist" property is set:
 
@@ -543,8 +548,8 @@ def validate_object_id(*args, allow_missing=_false, allow_optional=()):
     """
     Warns and returns the number of errors relating to objects within arrays lacking "id" fields.
 
-    If an array field's "wholeListMerge" property isn't set or is set to ``false``, then the object fields under it
-    must have an "id" field, and the "id" field must be required.
+    If an array field's "wholeListMerge" property isn't set or is set to ``false`` or ``null``, then the object fields
+    under it must have an "id" field, and the "id" field must be required.
 
     :param function allow_missing: a method that accepts a JSON Pointer, and returns whether the field is allowed to
                                    not have an "id" field
@@ -593,8 +598,8 @@ def validate_merge_properties(*args):
     """
     Warns and returns the number of errors relating to missing or extra merge properties.
 
-    The "omitWhenMerged" and "wholeListMerge" properties mustn't both be set, and musn't be set to ``false``. The
-    "wholeListMerge" property must be set on non-nullable arrays of objects only.
+    The "omitWhenMerged" and "wholeListMerge" properties mustn't both be set, and musn't be set to ``false`` or
+    ``null``. The "wholeListMerge" property must be set on non-nullable arrays of objects only.
 
     See https://standard.open-contracting.org/1.1/en/schema/merging/#whole-list-merge
 
@@ -613,11 +618,12 @@ def validate_merge_properties(*args):
         elif 'wholeListMerge' in data:
             if not is_array_of_objects(data):
                 errors += 1
-                warn('{} sets "wholeListMerge", though the field is not an array of objects, at {}'.format(path, pointer), MergePropertiesWarning)  # noqa: E501
+                warn('{} sets "wholeListMerge", though the field is not an array of objects, at {}'.format(
+                    path, pointer), MergePropertiesWarning)
             if 'omitWhenMerged' in data:
                 errors += 1
-                warn('{} sets both "omitWhenMerged" and "wholeListMerge" at {}'.format(path, pointer),
-                     MergePropertiesWarning)
+                warn('{} sets both "omitWhenMerged" and "wholeListMerge" at {}'.format(
+                    path, pointer), MergePropertiesWarning)
 
         return errors
 
@@ -639,7 +645,7 @@ def validate_ref(path, data):
         # `repr` causes the references to be loaded, if possible.
         repr(ref)
     except JsonRefError as e:
-        warn('{} has {} at {}'.format(path, e.message, '/'.join(e.path)), RefWarning)
+        warn('{} has {} at {}'.format(path, e.message, '/'.join(map(str, e.path))), RefWarning)
         return 1
 
     return 0
